# Sales Order

{message}

| Field | Value |
|-------|-------|
| **Order ID** | {id} |
| **Order Number** | {order_number} |
| **Customer ID** | {customer_id} |
| **Status** | {status} |
| **Total** | {total} |
| **Currency** | {currency} |

## Next Steps

{next_actions_text}
